import Button from "../Button/Button";
import { useEffect, useState } from "react";

interface ImageModeratorProps {
  token: string;
  apiUrl: string;
  middlewareUrl: string;
}

export default function ImageModerator({
  token,
  apiUrl,
  middlewareUrl,
}: ImageModeratorProps) {
  const acceptLabel = "Accept";
  const discardLabel = "Discard";

  const [isLoading, setIsLoading] = useState(true);
  const [imageData, setImageData] = useState({ url: "", tags: [] });
  const [imageAlt, setImageAlt] = useState("No image");

  function acceptAction() {
    fetch(`${apiUrl}/images`, {
      method: "POST",
      body: JSON.stringify({
        url: imageData.url,
        status: "available",
        tags: imageData.tags,
      }),
      headers: {
        "Content-type": "application/json",
        Authorization: `Bearer ${token}`,
      },
    });
    setIsLoading(true);
  }

  function discardAction() {
    fetch(`${apiUrl}/images`, {
      method: "POST",
      body: JSON.stringify({
        url: imageData.url,
        status: "unavailable",
        tags: imageData.tags,
      }),
      headers: {
        "Content-type": "application/json",
        Authorization: `Bearer ${token}`,
      },
    });
    setIsLoading(true);
  }

  const getNewImage = () => {
    setImageData({ url: "", tags: [] });
    fetch(`${middlewareUrl}/image`, {
      method: "GET",
    })
      .then((response) => {
        if (!response.ok) throw new Error("Response was not ok");
        return response.json();
      })
      .then((data) => {
        const url = data.url;
        const tags = data.tags;
        setImageData({ url, tags });
      })
      .catch((error) => {
        setImageAlt("Error");
        console.error(error);
      })
      .finally(() => {
        setIsLoading(false);
      });
  };

  useEffect(getNewImage, [isLoading]);

  return (
    <div
      style={{
        display: "grid",
        gridTemplateColumns: "1fr 1fr",
        gridTemplateRows: "1fr 50px",
        gridTemplateAreas: "'. .' '. .'",
        width: "100vw",
        height: "100vh",
      }}>
      {isLoading ? (
        <span>Loading...</span>
      ) : (
        <img
          src={imageData.url}
          alt={imageAlt}
          style={{
            width: "100%",
            height: "100%",
            gridColumnStart: 1,
            gridColumnEnd: 3,
            display: "block",
            objectFit: "contain",
          }}
        />
      )}
      <Button
        label={acceptLabel}
        action={acceptAction}
      />
      <Button
        label={discardLabel}
        action={discardAction}
      />
    </div>
  );
}
