import { useEffect, useState } from "react";

export default function Login({ setRemote }: { setRemote: Function }) {
  const sendLabel = "Login";
  const [middlewareUrl, setMiddlewareUrl] = useState("");
  const [apiUrl, setApiUrl] = useState("");
  const [app, setApp] = useState("");
  const [secret, setSecret] = useState("");

  function sendAction() {
    event?.preventDefault();
    try {
      if (apiUrl && middlewareUrl && app && secret) {
        localStorage.setItem(
          "credentials",
          JSON.stringify({ apiUrl, middlewareUrl, app, secret })
        );
      }
    } catch (error) {
      console.error(error);
    }
    fetch(`${apiUrl}/login`, {
      method: "POST",
      body: JSON.stringify({ app, secret }),
      headers: { "Content-type": "application/json" },
    })
      .then((response) => {
        return response.json();
      })
      .then((body) => {
        setRemote({ apiUrl, middlewareUrl, token: body.token });
      });
  }

  function handleChange(
    e: {
      target: { value: React.SetStateAction<string> };
    },
    setter: React.Dispatch<React.SetStateAction<string>>
  ): void {
    setter(e.target.value);
  }
  useEffect(() => {
    const savedRemote = localStorage.getItem("credentials");

    if (savedRemote) {
      const savedData = JSON.parse(savedRemote);
      setApiUrl(savedData.apiUrl);
      setMiddlewareUrl(savedData.middlewareUrl);
      setApp(savedData.app);
      setSecret(savedData.secret);
    }
  }, []);

  useEffect(() => {
    if (secret) {
      sendAction();
    }
  }, [secret]);

  return (
    <div
      style={{
        height: "100vh",
        width: "100vw",
      }}>
      <form
        style={{
          height: "100%",
          width: "100%",
          display: "flex",
          flexDirection: "column",
          justifyContent: "center",
          alignItems: "center",
        }}
        onSubmit={sendAction}>
        <label>API URL: </label>
        <input
          type="url"
          id="api"
          name="api"
          value={apiUrl}
          onChange={(e) => handleChange(e, setApiUrl)}
        />
        <label>Source URL: </label>
        <input
          type="url"
          id="middleware"
          name="middleware"
          value={middlewareUrl}
          onChange={(e) => handleChange(e, setMiddlewareUrl)}
        />
        <label>App name: </label>
        <input
          type="text"
          id="username"
          name="username"
          value={app}
          onChange={(e) => handleChange(e, setApp)}
        />
        <label>Secret: </label>
        <input
          type="password"
          value={secret}
          onChange={(e) => handleChange(e, setSecret)}
        />
        <button type="submit">{sendLabel}</button>
      </form>
    </div>
  );
}
